@@ -83,6 +83,7 @@ sub init {
 	$self->$_( $profile{$_}) for qw(autoRecalc columns mainColumn);
 	$self->autowidths unless scalar @{$profile{widths}};
 	$self->{recalc} = 1 if $profile{autoRecalc};
+	$self->{align} = ta::Left;
 	return %profile;
 }
 
@@ -135,11 +136,10 @@ sub draw_items
 	for (@widths) { $extent += $_ }
 	$canvas->backColor($clrs[3]);
 	for ( $i = 0; $i < $icount; $i++) {
-		my ($node, $x, $y, $x2, $y2, $position, $focused) = @{$$paintStruc[$i]};
+		my ($node, $x, $y, $x2, $y2, $position, $selected, $focused, $prelight) = @{$$paintStruc[$i]};
+		next unless $prelight || $selected;
 		$x = $xend + 1 if ($xend < $x);
-		if ($focused) {
-			$canvas->clear($x, $y, $extent, $y2);
-		}
+		$self->draw_item_background( $canvas, $x, $y, $extent, $y2, $prelight, $selected ? $clrs[3] : $clrs[1]);
 	}
 	$canvas->backColor($clrs[0]);
 
@@ -162,7 +162,7 @@ sub draw_items
 				$x = 2 - $o if ($ci);
 				my $c = $clrs[ $focused ? 2 : 0];
 				$canvas-> color( $c), $lc = $c if $c != $lc;
-				$canvas->text_out($node->[0]->[$ci], $x+$txw, $y);
+				$canvas->text_out_bidi($node->[0]->[$ci], $x+$txw, $y);
 			}
 		}
 		$xstart += $wx;
