@@ -34,7 +34,7 @@
 #define POLLUTE_NAME_SPACE 1
 #endif
 
-#define PRIMA_CORE_VERSION 2012080101
+#define PRIMA_CORE_VERSION 2015091401
 
 #define PRIMA_VERSION_BOOTCHECK \
     if(apc_get_core_version()!=PRIMA_CORE_VERSION) \
@@ -42,12 +42,6 @@
 
 #include "generic/config.h"
 
-#if (PERL_PATCHLEVEL < 4 || (( PERL_PATCHLEVEL == 4) && ( PERL_SUBVERSION <= 4)))
-#error "Prima require at least perl 5.005"
-#endif
-
-/* #define PARANOID_MALLOC */
-
 #ifdef _MSC_VER
    #define BROKEN_COMPILER       1
    #define BROKEN_PERL_PLATFORM  1
@@ -58,9 +52,6 @@
    #define HAVE_SNPRINTF         1
    #define HAVE_STRICMP          1
    #define HAVE_STRNICMP         1
-#elif defined( __BORLANDC__)
-   #define BROKEN_PERL_PLATFORM  1
-   #define BROKEN_COMPILER       1
 #elif defined(WIN32)
    #define BROKEN_PERL_PLATFORM  1
 #endif
@@ -138,13 +129,6 @@ public:
 extern "C" {
 #endif
 
-/*
-#undef realloc
-#undef malloc
-#undef free
-*/
-
-
 #if defined (package)
    #undef mod
    #undef list
@@ -258,15 +242,8 @@ extern "C" {
 #define SvPV_nolen(_sv)  SvPV(_sv,na)
 #endif
 
-#define PERL_CALL_SV_DIE_BUG_AWARE 1
-
-#ifdef PERL_CALL_SV_DIE_BUG_AWARE
 #define PERL_CALL_METHOD   clean_perl_call_method
 #define PERL_CALL_PV       clean_perl_call_pv
-#else
-#define PERL_CALL_METHOD   perl_call_method
-#define PERL_CALL_PV       perl_call_pv
-#endif
 
 #ifndef HAVE_BZERO
 extern void bzero(void*,size_t);
@@ -394,6 +371,9 @@ typedef __int64 int64_t;
 typedef unsigned long uint64_t;
 #endif
 #endif
+#if !defined(HAVE_SSIZE_T)
+typedef size_t ssize_t;
+#endif
 
 typedef uint32_t        Color;
 
@@ -1240,26 +1220,13 @@ extern FillPattern fillPatterns[];
 extern Bool
 kind_of( Handle object, void *cls);
 
-/* debugging functions */
-extern int
-debug_write( const char *format, ...);
-
 /* perl links */
-#if (PERL_PATCHLEVEL < 5)
-/* ...(perl stinks)... */
-#undef  SvREFCNT_inc
-#define SvREFCNT_inc(sv) ((Sv = (SV*)(sv)),             \
-                          (void)(Sv && ++SvREFCNT(Sv)), \
-                          (SV*)Sv)
-#endif
 
-#ifdef PERL_CALL_SV_DIE_BUG_AWARE
 extern I32
 clean_perl_call_method( char* methname, I32 flags);
 
 extern I32
 clean_perl_call_pv( char* subname, I32 flags);
-#endif
 
 extern void
 build_static_vmt( void *vmt);
@@ -1316,6 +1283,35 @@ unprotect_object( Handle obj);
 extern void
 kill_zombies( void);
 
+/*
+ exception_* functions are solely needed as a workaround of a Win64 bug when running 32-bit programs.
+ It can be manifested when a perl code dies in f.ex. onPaint, and the triggered longjmp is
+ expected to land somewhere in perl guts. Except it doesn't, and the next 32-bit executed code
+ is right after DispatchMessage.
+
+ Discussion on stackoverflow here:
+ http://stackoverflow.com/questions/32525561/64-bit-windows-longjmp-lands-in-a-wrong-place
+*/
+
+extern void
+exception_remember( char * text);
+
+extern Bool
+exception_charged();
+
+extern Bool
+exception_block( Bool block );
+
+extern void
+exception_check_raise( void );
+
+#if PRIMA_PLATFORM_X11
+#define EXCEPTION_CHECK_RAISE(v) exception_check_raise()
+#else
+#define EXCEPTION_CHECK_RAISE(v) if ( exception_charged()) return v;
+#endif
+
+
 extern HV*
 parse_hv( I32 ax, SV **sp, I32 items, SV **mark,
           int expected, const char *methodName);
@@ -1404,7 +1400,6 @@ SvBOOL( SV *sv)
 #define CWindow(h)                      (PWindow(h)-> self)
 #endif
 
-
 /* mapping functions */
 
 #define endCtx          0x19740108
@@ -1470,39 +1465,6 @@ extern int
 list_index_of( PList self, Handle item);
 
 /* utf8 */
-#if PERL_PATCHLEVEL > 5
-#define PERL_SUPPORTS_UTF8  1
-#if (PERL_PATCHLEVEL == 6)
-#define utf8_to_uvchr utf8_to_uv_simple
-#define utf8_to_uvuni utf8_to_uv_simple
-#define uvchr_to_utf8 uv_to_utf8
-#define uvuni_to_utf8 uv_to_utf8
-#endif
-#else
-/* dummy utf8 functionality */
-#undef utf8_hop
-#undef utf8_length
-#undef  PERL_SUPPORTS_UTF8
-#define IN_BYTES            1
-#define DO_UTF8(sv)         0
-#define SvUTF8(sv)          0
-#define utf8_length(s,e)    ((U8*)(e)-(U8*)(s))
-#define utf8_hop(s,off)     ((U8*)((s)+(off)))
-#define SvUTF8_on(sv)       {}
-#define SvUTF8_off(sv)      {}
-
-#define utf8_to_uvchr       prima_utf8_to_uv
-#define utf8_to_uvuni       prima_utf8_to_uv
-#define uvchr_to_utf8        prima_uv_to_utf8
-#define uvuni_to_utf8        prima_uv_to_utf8
-extern UV
-prima_utf8_to_uv( U8 * utf8, STRLEN * len);
-
-extern U8 *
-prima_uv_to_utf8( U8 * utf8, UV uv);
-
-#endif
-
 extern int
 prima_utf8_length( const char * utf8);
 
@@ -1512,8 +1474,6 @@ prima_is_utf8_sv( SV * sv);
 /* OS types */
 #define APC(const_name) CONSTANT(apc,const_name)
 START_TABLE(apc,UV)
-#define apcOs2                  1
-APC(Os2)
 #define apcWin32                2
 APC(Win32)
 #define apcUnix                 3
@@ -1594,6 +1554,8 @@ DT(QueryLinesDrawn)
 DT(NoWordWrap)
 #define dtWordWrap                 0x0000
 DT(WordWrap)
+#define dtBidiText                 0x8000
+DT(BidiText)
 #define dtDefault                  (dtNewLineBreak|dtWordBreak|dtExpandTabs|dtUseExternalLeading)
 DT(Default)
 
@@ -1886,7 +1848,6 @@ END_TABLE(sv,UV)
 #undef SV
 
 extern Handle application;
-extern long   apcError;
 
 /* *****************
 *  apc functions   *
@@ -3147,6 +3108,9 @@ apc_gp_arc( Handle self, int x, int y, int dX, int dY,
 extern Bool
 apc_gp_bar( Handle self, int x1, int y1, int x2, int y2);
 
+extern Bool
+apc_gp_bars( Handle self, int nr, Rect *rr);
+
 extern Bool
 apc_gp_clear( Handle self, int x1, int y1, int x2, int y2);
 
@@ -3483,79 +3447,13 @@ apc_query_drive_type( const char *drive);
 
 extern char*
 apc_get_user_name( void);
+
 extern PList
 apc_getdir( const char *dirname);
 
 extern Bool
 apc_dl_export(char *path);
 
-
-#define HOOK_EVENT_LOOP 0
-
-typedef Bool PrimaHookProc( void * message);
-
-extern  Bool
-apc_register_hook( int hookType, void * hookProc);
-
-extern  Bool
-apc_deregister_hook( int hookType, void * hookProc);
-
-extern  Bool
-apc_register_event( void * sysMessage);
-
-extern  Bool
-apc_deregister_event( void * sysMessage);
-
-
-
-/* Memory bugs debugging tools */
-#ifdef PARANOID_MALLOC
-extern void *
-_test_malloc( size_t size, int ln, char *fil, Handle self);
-
-extern void *
-_test_realloc( void * ptr, size_t size, int ln, char *fil, Handle self);
-
-extern void
-_test_free( void *ptr, int ln, char *fil, Handle self);
-
-#define plist_create( sz, delta) paranoid_plist_create( sz, delta, __FILE__, __LINE__)
-#define list_create( slf, sz, delta) paranoid_list_create( slf, sz, delta, __FILE__, __LINE__)
-extern PList
-paranoid_plist_create( int, int, char *, int);
-
-extern void
-paranoid_list_create( PList, int, int, char *, int);
-
-extern Handle self;
-
-#undef malloc
-#undef realloc
-#undef free
-#define realloc(ptr,sz) _test_realloc((ptr),(sz),__LINE__,__FILE__,self)
-#define malloc(sz) _test_malloc((sz),__LINE__,__FILE__,self)
-#define free(ptr) _test_free((ptr),__LINE__,__FILE__,self)
-#endif /* PARANOID_MALLOC */
-
-#if defined( USE_GC)
-#if defined( HAVE_GC_H)
-#define GC_DEBUG 1
-#include <gc.h>
-#undef malloc
-#undef free
-#undef realloc
-#define malloc( sz) GC_MALLOC( sz)
-#define free( p) GC_FREE( p)
-#define realloc( old, sz) GC_REALLOC( old, sz)
-#define CHECK_LEAKS GC_gcollect()
-#else
-#warning USE_GC requires presence of gc.h
-#define CHECK_LEAKS
-#endif /* HAVE_GC_H */
-#else
-#define CHECK_LEAKS
-#endif /* USE_GC */
-
 #ifdef __cplusplus
 }
 #endif
